check_and_notify

Function check_and_notify 

pub async fn check_and_notify()
Run the update check and print a notice if a newer version is available.

This should be called early in main() for non-upgrade commands. Uses cached results when available. When the cache is stale, performs an async HTTP request which can take up to REQUEST_TIMEOUT (5s).