pub fn detect_install_method() -> InstallMethodExpand description
Detect how devboy was installed by examining the binary path and environment variables.
pub fn detect_install_method() -> InstallMethodDetect how devboy was installed by examining the binary path and environment variables.