pub async fn resolve_version_status() -> VersionStatusExpand description
Resolve version status using the cache first, then GitHub as a fallback.
pub async fn resolve_version_status() -> VersionStatusResolve version status using the cache first, then GitHub as a fallback.